==> certificatemanager-1.100.0-sources.jar: software/amazon/awscdk/services/certificatemanager/CfnAccount.java <==
package software.amazon.awscdk.services.certificatemanager;

/**
 * A CloudFormation `AWS::CertificateManager::Account`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:22.519Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.certificatemanager.$Module.class, fqn = "@aws-cdk/aws-certificatemanager.CfnAccount")
public class CfnAccount extends software.amazon.awscdk.core.CfnResource implements software.amazon.awscdk.core.IInspectable {

    protected CfnAccount(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CfnAccount(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        CFN_RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.certificatemanager.CfnAccount.class, "CFN_RESOURCE_TYPE_NAME", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * Create a new `AWS::CertificateManager::Account`.
     * <p>
     * @param scope - scope in which this resource is defined. This parameter is required.
     * @param id - scoped id of the resource. This parameter is required.
     * @param props - resource properties. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public CfnAccount(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.certificatemanager.CfnAccountProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) Examines the CloudFormation resource and discloses attributes.
     * <p>
     * @param inspector - tree inspector to collect and process attributes. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void inspect(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.TreeInspector inspector) {
        software.amazon.jsii.Kernel.call(this, "inspect", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(inspector, "inspector is required") });
    }

    /**
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    protected @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> renderProperties(final @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> props) {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.call(this, "renderProperties", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)), new Object[] { java.util.Objects.requireNonNull(props, "props is required") }));
    }

    /**
     * The CloudFormation resource type name for this resource class.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String CFN_RESOURCE_TYPE_NAME;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getAttrAccountId() {
        return software.amazon.jsii.Kernel.get(this, "attrAccountId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> getCfnProperties() {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.get(this, "cfnProperties", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class))));
    }

    /**
     * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getExpiryEventsConfiguration() {
        return software.amazon.jsii.Kernel.get(this, "expiryEventsConfiguration", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setExpiryEventsConfiguration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.certificatemanager.CfnAccount.ExpiryEventsConfigurationProperty value) {
        software.amazon.jsii.Kernel.set(this, "expiryEventsConfiguration", java.util.Objects.requireNonNull(value, "expiryEventsConfiguration is required"));
    }

    /**
     * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setExpiryEventsConfiguration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "expiryEventsConfiguration", java.util.Objects.requireNonNull(value, "expiryEventsConfiguration is required"));
    }
    /**
     */
    @software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.certificatemanager.$Module.class, fqn = "@aws-cdk/aws-certificatemanager.CfnAccount.ExpiryEventsConfigurationProperty")
    @software.amazon.jsii.Jsii.Proxy(ExpiryEventsConfigurationProperty.Jsii$Proxy.class)
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static interface ExpiryEventsConfigurationProperty extends software.amazon.jsii.JsiiSerializable {

        /**
         * `CfnAccount.ExpiryEventsConfigurationProperty.DaysBeforeExpiry`.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.Nullable java.lang.Number getDaysBeforeExpiry() {
            return null;
        }

        /**
         * @return a {@link Builder} of {@link ExpiryEventsConfigurationProperty}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        static Builder builder() {
            return new Builder();
        }
        /**
         * A builder for {@link ExpiryEventsConfigurationProperty}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static final class Builder implements software.amazon.jsii.Builder<ExpiryEventsConfigurationProperty> {
            private java.lang.Number daysBeforeExpiry;

            /**
             * Sets the value of {@link ExpiryEventsConfigurationProperty#getDaysBeforeExpiry}
             * @param daysBeforeExpiry `CfnAccount.ExpiryEventsConfigurationProperty.DaysBeforeExpiry`.
             * @return {@code this}
             */
            @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
            public Builder daysBeforeExpiry(java.lang.Number daysBeforeExpiry) {
                this.daysBeforeExpiry = daysBeforeExpiry;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link ExpiryEventsConfigurationProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
            @Override
            public ExpiryEventsConfigurationProperty build() {
                return new Jsii$Proxy(daysBeforeExpiry);
            }
        }

        /**
         * An implementation for {@link ExpiryEventsConfigurationProperty}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @software.amazon.jsii.Internal
        final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ExpiryEventsConfigurationProperty {
            private final java.lang.Number daysBeforeExpiry;

            /**
             * Constructor that initializes the object based on values retrieved from the JsiiObject.
             * @param objRef Reference to the JSII managed object.
             */
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
                super(objRef);
                this.daysBeforeExpiry = software.amazon.jsii.Kernel.get(this, "daysBeforeExpiry", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            }

            /**
             * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
             */
            protected Jsii$Proxy(final java.lang.Number daysBeforeExpiry) {
                super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
                this.daysBeforeExpiry = daysBeforeExpiry;
            }

            @Override
            public final java.lang.Number getDaysBeforeExpiry() {
                return this.daysBeforeExpiry;
            }

            @Override
            @software.amazon.jsii.Internal
            public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

                if (this.getDaysBeforeExpiry() != null) {
                    data.set("daysBeforeExpiry", om.valueToTree(this.getDaysBeforeExpiry()));
                }

                final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                struct.set("fqn", om.valueToTree("@aws-cdk/aws-certificatemanager.CfnAccount.ExpiryEventsConfigurationProperty"));
                struct.set("data", data);

                final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                obj.set("$jsii.struct", struct);

                return obj;
            }

            @Override
            public final boolean equals(final Object o) {
                if (this == o) return true;
                if (o == null || getClass() != o.getClass()) return false;

                ExpiryEventsConfigurationProperty.Jsii$Proxy that = (ExpiryEventsConfigurationProperty.Jsii$Proxy) o;

                return this.daysBeforeExpiry != null ? this.daysBeforeExpiry.equals(that.daysBeforeExpiry) : that.daysBeforeExpiry == null;
            }

            @Override
            public final int hashCode() {
                int result = this.daysBeforeExpiry != null ? this.daysBeforeExpiry.hashCode() : 0;
                return result;
            }
        }
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.certificatemanager.CfnAccount}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.certificatemanager.CfnAccount> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - scope in which this resource is defined. This parameter is required.
         * @param id - scoped id of the resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.certificatemanager.CfnAccountProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.certificatemanager.CfnAccountProps.Builder();
        }

        /**
         * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
         * <p>
         * @return {@code this}
         * @param expiryEventsConfiguration `AWS::CertificateManager::Account.ExpiryEventsConfiguration`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder expiryEventsConfiguration(final software.amazon.awscdk.services.certificatemanager.CfnAccount.ExpiryEventsConfigurationProperty expiryEventsConfiguration) {
            this.props.expiryEventsConfiguration(expiryEventsConfiguration);
            return this;
        }
        /**
         * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
         * <p>
         * @return {@code this}
         * @param expiryEventsConfiguration `AWS::CertificateManager::Account.ExpiryEventsConfiguration`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder expiryEventsConfiguration(final software.amazon.awscdk.core.IResolvable expiryEventsConfiguration) {
            this.props.expiryEventsConfiguration(expiryEventsConfiguration);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.certificatemanager.CfnAccount}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.certificatemanager.CfnAccount build() {
            return new software.amazon.awscdk.services.certificatemanager.CfnAccount(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> certificatemanager-1.101.0-sources.jar: software/amazon/awscdk/services/certificatemanager/CfnAccount.java <==
package software.amazon.awscdk.services.certificatemanager;

/**
 * A CloudFormation `AWS::CertificateManager::Account`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:51.462Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.certificatemanager.$Module.class, fqn = "@aws-cdk/aws-certificatemanager.CfnAccount")
public class CfnAccount extends software.amazon.awscdk.core.CfnResource implements software.amazon.awscdk.core.IInspectable {

    protected CfnAccount(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CfnAccount(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        CFN_RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.certificatemanager.CfnAccount.class, "CFN_RESOURCE_TYPE_NAME", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * Create a new `AWS::CertificateManager::Account`.
     * <p>
     * @param scope - scope in which this resource is defined. This parameter is required.
     * @param id - scoped id of the resource. This parameter is required.
     * @param props - resource properties. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public CfnAccount(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.certificatemanager.CfnAccountProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Examines the CloudFormation resource and discloses attributes.
     * <p>
     * @param inspector - tree inspector to collect and process attributes. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void inspect(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.TreeInspector inspector) {
        software.amazon.jsii.Kernel.call(this, "inspect", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(inspector, "inspector is required") });
    }

    /**
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    protected @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> renderProperties(final @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> props) {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.call(this, "renderProperties", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)), new Object[] { java.util.Objects.requireNonNull(props, "props is required") }));
    }

    /**
     * The CloudFormation resource type name for this resource class.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String CFN_RESOURCE_TYPE_NAME;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getAttrAccountId() {
        return software.amazon.jsii.Kernel.get(this, "attrAccountId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> getCfnProperties() {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.get(this, "cfnProperties", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class))));
    }

    /**
     * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getExpiryEventsConfiguration() {
        return software.amazon.jsii.Kernel.get(this, "expiryEventsConfiguration", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setExpiryEventsConfiguration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.certificatemanager.CfnAccount.ExpiryEventsConfigurationProperty value) {
        software.amazon.jsii.Kernel.set(this, "expiryEventsConfiguration", java.util.Objects.requireNonNull(value, "expiryEventsConfiguration is required"));
    }

    /**
     * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setExpiryEventsConfiguration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "expiryEventsConfiguration", java.util.Objects.requireNonNull(value, "expiryEventsConfiguration is required"));
    }
    /**
     */
    @software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.certificatemanager.$Module.class, fqn = "@aws-cdk/aws-certificatemanager.CfnAccount.ExpiryEventsConfigurationProperty")
    @software.amazon.jsii.Jsii.Proxy(ExpiryEventsConfigurationProperty.Jsii$Proxy.class)
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static interface ExpiryEventsConfigurationProperty extends software.amazon.jsii.JsiiSerializable {

        /**
         * `CfnAccount.ExpiryEventsConfigurationProperty.DaysBeforeExpiry`.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.Nullable java.lang.Number getDaysBeforeExpiry() {
            return null;
        }

        /**
         * @return a {@link Builder} of {@link ExpiryEventsConfigurationProperty}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        static Builder builder() {
            return new Builder();
        }
        /**
         * A builder for {@link ExpiryEventsConfigurationProperty}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static final class Builder implements software.amazon.jsii.Builder<ExpiryEventsConfigurationProperty> {
            private java.lang.Number daysBeforeExpiry;

            /**
             * Sets the value of {@link ExpiryEventsConfigurationProperty#getDaysBeforeExpiry}
             * @param daysBeforeExpiry `CfnAccount.ExpiryEventsConfigurationProperty.DaysBeforeExpiry`.
             * @return {@code this}
             */
            @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
            public Builder daysBeforeExpiry(java.lang.Number daysBeforeExpiry) {
                this.daysBeforeExpiry = daysBeforeExpiry;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link ExpiryEventsConfigurationProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
            @Override
            public ExpiryEventsConfigurationProperty build() {
                return new Jsii$Proxy(daysBeforeExpiry);
            }
        }

        /**
         * An implementation for {@link ExpiryEventsConfigurationProperty}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @software.amazon.jsii.Internal
        final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ExpiryEventsConfigurationProperty {
            private final java.lang.Number daysBeforeExpiry;

            /**
             * Constructor that initializes the object based on values retrieved from the JsiiObject.
             * @param objRef Reference to the JSII managed object.
             */
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
                super(objRef);
                this.daysBeforeExpiry = software.amazon.jsii.Kernel.get(this, "daysBeforeExpiry", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            }

            /**
             * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
             */
            protected Jsii$Proxy(final java.lang.Number daysBeforeExpiry) {
                super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
                this.daysBeforeExpiry = daysBeforeExpiry;
            }

            @Override
            public final java.lang.Number getDaysBeforeExpiry() {
                return this.daysBeforeExpiry;
            }

            @Override
            @software.amazon.jsii.Internal
            public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

                if (this.getDaysBeforeExpiry() != null) {
                    data.set("daysBeforeExpiry", om.valueToTree(this.getDaysBeforeExpiry()));
                }

                final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                struct.set("fqn", om.valueToTree("@aws-cdk/aws-certificatemanager.CfnAccount.ExpiryEventsConfigurationProperty"));
                struct.set("data", data);

                final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                obj.set("$jsii.struct", struct);

                return obj;
            }

            @Override
            public final boolean equals(final Object o) {
                if (this == o) return true;
                if (o == null || getClass() != o.getClass()) return false;

                ExpiryEventsConfigurationProperty.Jsii$Proxy that = (ExpiryEventsConfigurationProperty.Jsii$Proxy) o;

                return this.daysBeforeExpiry != null ? this.daysBeforeExpiry.equals(that.daysBeforeExpiry) : that.daysBeforeExpiry == null;
            }

            @Override
            public final int hashCode() {
                int result = this.daysBeforeExpiry != null ? this.daysBeforeExpiry.hashCode() : 0;
                return result;
            }
        }
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.certificatemanager.CfnAccount}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.certificatemanager.CfnAccount> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - scope in which this resource is defined. This parameter is required.
         * @param id - scoped id of the resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.certificatemanager.CfnAccountProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.certificatemanager.CfnAccountProps.Builder();
        }

        /**
         * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
         * <p>
         * @return {@code this}
         * @param expiryEventsConfiguration `AWS::CertificateManager::Account.ExpiryEventsConfiguration`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder expiryEventsConfiguration(final software.amazon.awscdk.services.certificatemanager.CfnAccount.ExpiryEventsConfigurationProperty expiryEventsConfiguration) {
            this.props.expiryEventsConfiguration(expiryEventsConfiguration);
            return this;
        }
        /**
         * `AWS::CertificateManager::Account.ExpiryEventsConfiguration`.
         * <p>
         * @return {@code this}
         * @param expiryEventsConfiguration `AWS::CertificateManager::Account.ExpiryEventsConfiguration`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder expiryEventsConfiguration(final software.amazon.awscdk.core.IResolvable expiryEventsConfiguration) {
            this.props.expiryEventsConfiguration(expiryEventsConfiguration);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.certificatemanager.CfnAccount}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.certificatemanager.CfnAccount build() {
            return new software.amazon.awscdk.services.certificatemanager.CfnAccount(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
